==> haskell-split-0.2.3.4-155-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-split.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 split
version:              0.2.3.4
visibility:           public
id:                   split-0.2.3.4-APMQKFcl31oIYOk4dvIO8m
key:                  split-0.2.3.4-APMQKFcl31oIYOk4dvIO8m
license:              BSD-3-Clause
copyright:            (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer:           byorgey@gmail.com
author:               Brent Yorgey
stability:            stable
synopsis:             Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:

    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).

    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.

    To get started, see the "Data.List.Split" module.

category:             List
abi:                  f256ddeba2c33da441e6960eeba05292
exposed:              True
exposed-modules:      Data.List.Split Data.List.Split.Internals
import-dirs:          /usr/lib/ghc-9.0.1/site-local/split-0.2.3.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/split-0.2.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/split-0.2.3.4
hs-libraries:         HSsplit-0.2.3.4-APMQKFcl31oIYOk4dvIO8m
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-split/html/split.haddock
haddock-html:         /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-split-0.2.3.4-156-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-split.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 split
version:              0.2.3.4
visibility:           public
id:                   split-0.2.3.4-nugq0vWLHr1Xv58VTP1Gn
key:                  split-0.2.3.4-nugq0vWLHr1Xv58VTP1Gn
license:              BSD-3-Clause
copyright:            (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer:           byorgey@gmail.com
author:               Brent Yorgey
stability:            stable
synopsis:             Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:

    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).

    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.

    To get started, see the "Data.List.Split" module.

category:             List
abi:                  50cd1cc68ec8d03c856d6f494c16b7ec
exposed:              True
exposed-modules:      Data.List.Split Data.List.Split.Internals
import-dirs:          /usr/lib/ghc-9.0.1/site-local/split-0.2.3.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/split-0.2.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/split-0.2.3.4
hs-libraries:         HSsplit-0.2.3.4-nugq0vWLHr1Xv58VTP1Gn
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-split/html/split.haddock
haddock-html:         /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
